unittest

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 4, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AssertDiagHasError

func AssertDiagHasError(t *testing.T, diags hcl.Diagnostics, want string)

AssertDiagHasError asserts that diags contains at least one error hcl.Diagnostic with the given summary. On failure it reports the missing summary and logs all summaries present in diags.

Types

This section is empty.

Jump to