Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertDiagHasError ¶
func AssertDiagHasError(t *testing.T, diags hcl.Diagnostics, want string)
AssertDiagHasError asserts that diags contains at least one error hcl.Diagnostic with the given summary. On failure it reports the missing summary and logs all summaries present in diags.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.